==> dapware-ram-1.0.0.0006-sources.jar: com/digiwin/dap/middle/ram/domain/GrantVO.java <==
package com.digiwin.dap.middle.ram.domain;

import com.digiwin.dap.middle.ram.domain.page.Page;
import com.digiwin.dap.middle.ram.entity.Grant;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 授权信息
 *
 * @author Xiao
 * @date 2021/8/16 16:36
 */
public class GrantVO extends Page {

    private Long sid;
    private String type;
    private String targetId;
    private String policyId;
    private String policyName;
    private String policyType;
    private LocalDateTime attachDate;
    private List<PolicyVO> policies;

    public GrantVO() {
    }

    public GrantVO(Grant grant, List<PolicyVO> policies) {
        this.sid = grant.getSid();
        this.type = grant.getType();
        this.policies = policies;
    }

    public Long getSid() {
        return sid;
    }

    public void setSid(Long sid) {
        this.sid = sid;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTargetId() {
        return targetId;
    }

    public void setTargetId(String targetId) {
        this.targetId = targetId;
    }

    public String getPolicyId() {
        return policyId;
    }

    public void setPolicyId(String policyId) {
        this.policyId = policyId;
    }

    public String getPolicyName() {
        return policyName;
    }

    public void setPolicyName(String policyName) {
        this.policyName = policyName;
    }

    public String getPolicyType() {
        return policyType;
    }

    public void setPolicyType(String policyType) {
        this.policyType = policyType;
    }

    public LocalDateTime getAttachDate() {
        return attachDate;
    }

    public void setAttachDate(LocalDateTime attachDate) {
        this.attachDate = attachDate;
    }

    public List<PolicyVO> getPolicies() {
        return policies;
    }

    public void setPolicies(List<PolicyVO> policies) {
        this.policies = policies;
    }
}

==> dapware-ram-2.2.1.1000-sources.jar: com/digiwin/dap/middle/ram/domain/GrantVO.java <==
package com.digiwin.dap.middle.ram.domain;

import com.digiwin.dap.middle.ram.domain.page.Page;

import java.time.LocalDateTime;

/**
 * 授权信息
 *
 * @author Xiao
 * @date 2021/8/16 16:36
 */
public class GrantVO extends Page {

    private Long sid;
    private String app;
    private String type;
    private String targetId;
    private String policyId;
    private String policyName;
    private String policyType;
    private LocalDateTime createDate;
    private LocalDateTime attachDate;
    private Integer policyCount;

    public Long getSid() {
        return sid;
    }

    public void setSid(Long sid) {
        this.sid = sid;
    }

    public String getApp() {
        return app;
    }

    public void setApp(String app) {
        this.app = app;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTargetId() {
        return targetId;
    }

    public void setTargetId(String targetId) {
        this.targetId = targetId;
    }

    public String getPolicyId() {
        return policyId;
    }

    public void setPolicyId(String policyId) {
        this.policyId = policyId;
    }

    public String getPolicyName() {
        return policyName;
    }

    public void setPolicyName(String policyName) {
        this.policyName = policyName;
    }

    public String getPolicyType() {
        return policyType;
    }

    public void setPolicyType(String policyType) {
        this.policyType = policyType;
    }

    public LocalDateTime getCreateDate() {
        return createDate;
    }

    public void setCreateDate(LocalDateTime createDate) {
        this.createDate = createDate;
    }

    public LocalDateTime getAttachDate() {
        return attachDate;
    }

    public void setAttachDate(LocalDateTime attachDate) {
        this.attachDate = attachDate;
    }

    public Integer getPolicyCount() {
        return policyCount;
    }

    public void setPolicyCount(Integer policyCount) {
        this.policyCount = policyCount;
    }
}
